@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # MIT License
 
-# Copyright (c) 2018 Ingate Systems AB
+# Copyright (c) 2021 Ingate Systems AB
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -773,6 +773,18 @@ class Client(object):
         else:
             raise SdkAuthError('Failed to authenticate (%s)' % (reason))
 
+    def destroy_token(self):
+        """Destroy an acquired authentication token. Note, a token will always
+           have an expiry time out (invoking this method will delete the token
+           prematurely).
+        """
+        if not self.__auth_token:
+            raise SdkAuthError('Please authenticate first')
+        response = self.__run_command('PUT', 'destroy-token')
+        self.__token = None
+        self.__auth_token = None
+        return response
+
     def unit_information(self):
         """Get information about the unit.
         """
@@ -843,6 +855,16 @@ class Client(object):
         self.authenticate()
         return response
 
+    def restart_sip(self):
+        """Restart the SIP module and remove all state, like registrations etc.
+        """
+        return self.__run_command('PUT', 'restart-sip')
+
+    def sip_status(self):
+        """Return SIP status information and metrics.
+        """
+        return self.__run_command('GET', 'sip-status')
+
     def store_edit(self, no_response=False):
         """Store the preliminary configuration to the permanent configuration.
 
